@@ -1,7 +1,8 @@
 /*
  * FileTranscoder interface for MP3FS
  *
- * Copyright (C) David Collett (daveco@users.sourceforge.net)
+ * Copyright (C) 2006-2008 David Collett
+ * Copyright (C) 2008-2010 Kristofer Henriksson
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,50 +23,48 @@
 #include <FLAC/stream_decoder.h>
 #include <lame/lame.h>
 #include <id3tag.h>
+#include <syslog.h>
 
-#include "class.h"
-#include "stringio.h"
-
-#define MP3_QUALITY 5
 #define FLAC_BLOCKSIZE 4608
 #define BUFSIZE 2 * FLAC_BLOCKSIZE
 
-// a list of currently opened files
-FILE *logfd;
-const char *basepath;
-int bitrate;
+/* Global program parameters */
+struct mp3fs_params {
+    const char *basepath;
+    unsigned int bitrate;
+    unsigned int quality;
+    int debug;
+};
 
-/** This is used for debugging. */
-#ifndef __DEBUG__
-#define DEBUG(f, x, ...)
-#else
-#define DEBUG(f, x, ...) do { \
-    fprintf(f, "%s:%u ",__FUNCTION__,__LINE__); \
-    fprintf(f, x, ## __VA_ARGS__); \
-    fflush(f); \
-  } while(0)
-#endif
+#define mp3fs_debug(f, ...) syslog(LOG_DEBUG, f, ## __VA_ARGS__)
+#define mp3fs_info(f, ...) syslog(LOG_INFO, f, ## __VA_ARGS__)
+#define mp3fs_error(f, ...) syslog(LOG_ERR, f, ## __VA_ARGS__)
+
+/* Internal buffer used for output file */
+struct mp3_buffer {
+    uint8_t* data;
+    unsigned long pos;
+    unsigned long size;
+};
+
+/* Transcoder parameters for open mp3 */
+struct transcoder {
+    struct mp3_buffer buffer;
+    unsigned long totalsize;
 
-CLASS(FileTranscoder, Object)
-    StringIO buffer;
-    int readptr;
-    int framesize;
-    int numframes;
-    int totalsize;
-    char *name;
-    char *orig_name;
     struct id3_tag *id3tag;
     char id3v1tag[128];
 
-    lame_global_flags *encoder;
     FLAC__StreamDecoder *decoder;
+    lame_global_flags *encoder;
+
     FLAC__StreamMetadata_StreamInfo info;
-    short int lbuf[FLAC_BLOCKSIZE];
-    short int rbuf[FLAC_BLOCKSIZE];
+
     unsigned char mp3buf[BUFSIZE];
+};
 
-    FileTranscoder METHOD(FileTranscoder, Con, char *filename);
-    int METHOD(FileTranscoder, Read, char *buff, int offset, int len);
-    int METHOD(FileTranscoder, Finish);
-
-END_CLASS
+struct transcoder* transcoder_new(char *flacname);
+int transcoder_read(struct transcoder* trans, char* buff, int offset,
+                    int len);
+int transcoder_finish(struct transcoder* trans);
+void transcoder_delete(struct transcoder* trans);
